# pyqtcolordialog

A drop-in replacement of `QColorDialog` for `PyQt5`.

![](docs/new.png)

For comparison, here's the default Qt color picker:

![](docs/old.png)

## Video preview

Ring mode (default):

[![](docs/ring.png)](https://rawcdn.githack.com/rr-/pyqtcolordialog/db9db87510bb855bf25cdd88eb051c9e9ca4f06d/docs/ring.webm)

Square mode:

[![](docs/square.png)](https://rawcdn.githack.com/rr-/pyqtcolordialog/db9db87510bb855bf25cdd88eb051c9e9ca4f06d/docs/square.webm)

## Installation

`pip install pyqtcolordialog --user`
